use strict;
use warnings;
use Tie::File;

sub setparam {

    my ($file, $key1, $key2, $val) = @_;

    # Purpose: Modify or set the value for a parameter in the master
    # or continue file. If the parameter is found it is modified using
    # the given value, otherwise it is added at the end of the file.
    #
    # Input arguments:
    #   $file        - Name of master/continue file
    #   $key1        - First parameter key
    #   $key2        - Second parameter key
    #   $val         - Value to assign
    #
    # Return values:
    #   none
    
    # Open the input file
    tie my @array, 'Tie::File', $file or die 
	"Unable to open file $file in setparam\n";
	
	
	# loop over all the lines and set the given parameter to the new value
	my $param_edited = 0;
	foreach my $line(@array) {
        my @fields = split(' ',$line);
        next unless $#fields eq 2;
        my ($k1, $k2, $v) = @fields;
        next unless $k1 eq $key1;
        next unless $k2 eq $key2;
        $line = "$key1 $key2 $val\n";
        $param_edited = 1;
        last;
    }

    unless ($param_edited) {
        push @array, "$$key1 $key2 $val\n";
    }
    untie @array; 
    return;
}
1;
